@@ -18,7 +18,6 @@
 
 #include <QApplication>
 #include <QDesktopServices>
-#include <QDesktopWidget>
 #include <QJsonArray>
 #include <QLayout>
 #include <QProcess>
@@ -29,8 +28,8 @@
 #include <QUrl>
 
 #ifndef KCONFIGWIDGETS_NO_KAUTH
-#include <KAuthAction>
-#include <KAuthObjectDecorator>
+#include <KAuth/Action>
+#include <KAuth/ObjectDecorator>
 #endif
 #include <KGuiItem>
 #include <KIconUtils>
@@ -43,7 +42,7 @@
 bool KCMultiDialogPrivate::resolveChanges(KCModuleProxy *currentProxy)
 {
     Q_Q(KCMultiDialog);
-    if (!currentProxy || !currentProxy->changed()) {
+    if (!currentProxy || !currentProxy->isChanged()) {
         return true;
     }
 
@@ -133,7 +132,7 @@ void KCMultiDialogPrivate::_k_clientChanged()
     bool change = false;
     bool defaulted = false;
     if (activeModule) {
-        change = activeModule->changed();
+        change = activeModule->isChanged();
         defaulted = activeModule->defaulted();
 
         QPushButton *applyButton = q->buttonBox()->button(QDialogButtonBox::Apply);
@@ -228,13 +227,27 @@ void KCMultiDialogPrivate::_k_updateHeader(bool use, const QString &message)
     KPageWidgetItem *item = q->currentPage();
     KCModuleProxy *kcm = qobject_cast<KCModuleProxy *>(item->widget());
 
+    QString moduleName;
+    QString icon;
+
+    if (kcm->metaData().isValid()) {
+        moduleName = kcm->metaData().name();
+        icon = kcm->metaData().iconName();
+    }
+
+#if KCMUTILS_BUILD_DEPRECATED_SINCE(5, 88)
+    if (kcm->moduleInfo().isValid()) {
+        moduleName = kcm->moduleInfo().moduleName();
+        icon = kcm->moduleInfo().icon();
+    }
+#endif
+
     if (use) {
-        item->setHeader(QStringLiteral("<b>") + kcm->moduleInfo().moduleName() + QStringLiteral("</b><br><i>") + message + QStringLiteral("</i>"));
-        item->setIcon(
-            KIconUtils::addOverlay(QIcon::fromTheme(kcm->moduleInfo().icon()), QIcon::fromTheme(QStringLiteral("dialog-warning")), Qt::BottomRightCorner));
+        item->setHeader(QStringLiteral("<b>") + moduleName + QStringLiteral("</b><br><i>") + message + QStringLiteral("</i>"));
+        item->setIcon(KIconUtils::addOverlay(QIcon::fromTheme(icon), QIcon::fromTheme(QStringLiteral("dialog-warning")), Qt::BottomRightCorner));
     } else {
-        item->setHeader(kcm->moduleInfo().moduleName());
-        item->setIcon(QIcon::fromTheme(kcm->moduleInfo().icon()));
+        item->setHeader(moduleName);
+        item->setIcon(QIcon::fromTheme(icon));
     }
 }
 
@@ -308,11 +321,9 @@ void KCMultiDialog::showEvent(QShowEvent *ev)
      * We adjust the size after passing the show event
      * because otherwise window pos is set to (0,0)
      */
-    QScreen *screen = QApplication::screenAt(pos());
-    if (screen) {
-        const QSize maxSize = screen->availableGeometry().size();
-        resize(qMin(sizeHint().width(), maxSize.width()), qMin(sizeHint().height(), maxSize.height()));
-    }
+
+    const QSize maxSize = screen()->availableGeometry().size();
+    resize(qMin(sizeHint().width(), maxSize.width()), qMin(sizeHint().height(), maxSize.height()));
 }
 
 void KCMultiDialog::slotDefaultClicked()
@@ -364,11 +375,12 @@ void KCMultiDialogPrivate::apply()
     Q_Q(KCMultiDialog);
     QStringList updatedComponents;
 
-    for (const CreatedModule &module : qAsConst(modules)) {
+    for (const CreatedModule &module : std::as_const(modules)) {
         KCModuleProxy *proxy = module.kcm;
 
-        if (proxy->changed()) {
+        if (proxy->isChanged()) {
             proxy->save();
+#if KCMUTILS_BUILD_DEPRECATED_SINCE(5, 85)
             /**
              * Add name of the components the kcm belongs to the list
              * of updated components.
@@ -379,13 +391,16 @@ void KCMultiDialogPrivate::apply()
                     updatedComponents.append(componentName);
                 }
             }
+#endif
         }
     }
 
+#if KCMUTILS_BUILD_DEPRECATED_SINCE(5, 85)
     // Send the configCommitted signal for every updated component.
-    for (const QString &name : qAsConst(updatedComponents)) {
+    for (const QString &name : std::as_const(updatedComponents)) {
         Q_EMIT q->configCommitted(name.toLatin1());
     }
+#endif
 
     Q_EMIT q->configCommitted();
 }
@@ -418,7 +433,9 @@ void KCMultiDialog::slotHelpClicked()
     QString docPath;
     for (int i = 0; i < d->modules.count(); ++i) {
         if (d->modules[i].item == item) {
+#if KCMUTILS_BUILD_DEPRECATED_SINCE(5, 88)
             docPath = d->modules[i].kcm->moduleInfo().docPath();
+#endif
             if (docPath.isEmpty()) {
                 docPath = d->modules[i].kcm->metaData().value(QStringLiteral("X-DocPath"));
             }
@@ -428,7 +445,7 @@ void KCMultiDialog::slotHelpClicked()
 
     const QUrl docUrl = QUrl(QStringLiteral("help:/")).resolved(QUrl(docPath)); // same code as in KHelpClient::invokeHelp
     const QString docUrlScheme = docUrl.scheme();
-    if (docUrlScheme == QLatin1String("help") || docUrlScheme == QLatin1String("man") || docUrlScheme == QLatin1String("info")) {
+    if (docUrlScheme == QLatin1String("man") || docUrlScheme == QLatin1String("info")) {
         QProcess::startDetached(QStringLiteral("khelpcenter"), QStringList() << docUrl.toString());
     } else {
         QDesktopServices::openUrl(docUrl);
@@ -445,12 +462,17 @@ void KCMultiDialog::closeEvent(QCloseEvent *event)
      * in other situations will lead to "module already loaded in Foo," while to the user
      * doesn't appear so(the dialog is hidden)
      */
-    for (auto &proxy : qAsConst(d->modules)) {
+    for (auto &proxy : std::as_const(d->modules)) {
         proxy.kcm->deleteClient();
     }
 }
 
 KPageWidgetItem *KCMultiDialog::addModule(const KPluginMetaData &metaData)
+{
+    return addModule(metaData, QStringList());
+}
+
+KPageWidgetItem *KCMultiDialog::addModule(const KPluginMetaData &metaData, const QStringList &args)
 {
     Q_D(KCMultiDialog);
     // Create the scroller
@@ -460,7 +482,7 @@ KPageWidgetItem *KCMultiDialog::addModule(const KPluginMetaData &metaData)
     moduleScroll->setFrameStyle(QFrame::NoFrame);
     moduleScroll->viewport()->setAutoFillBackground(false);
 
-    KCModuleProxy *kcm = new KCModuleProxy(metaData, moduleScroll, QStringList());
+    KCModuleProxy *kcm = new KCModuleProxy(metaData, moduleScroll, args);
     moduleScroll->setWidget(kcm);
 
     KPageWidgetItem *item = new KPageWidgetItem(moduleScroll, metaData.name());
@@ -508,7 +530,7 @@ KPageWidgetItem *KCMultiDialog::addModule(const KPluginMetaData &metaData)
         addPage(item);
     }
 
-    QObject::connect(kcm, QOverload<bool>::of(&KCModuleProxy::changed), this, [d]() {
+    QObject::connect(kcm, qOverload<bool>(&KCModuleProxy::changed), this, [d]() {
         d->_k_clientChanged();
     });
 
@@ -523,6 +545,7 @@ KPageWidgetItem *KCMultiDialog::addModule(const KPluginMetaData &metaData)
     return item;
 }
 
+#if KCMUTILS_BUILD_DEPRECATED_SINCE(5, 85)
 KPageWidgetItem *KCMultiDialog::addModule(const QString &path, const QStringList &args)
 {
     QString complete = path;
@@ -535,7 +558,9 @@ KPageWidgetItem *KCMultiDialog::addModule(const QString &path, const QStringList
 
     return addModule(KCModuleInfo(service), nullptr, args);
 }
+#endif
 
+#if KCMUTILS_BUILD_DEPRECATED_SINCE(5, 85)
 KPageWidgetItem *KCMultiDialog::addModule(const KCModuleInfo &moduleInfo, KPageWidgetItem *parentItem, const QStringList &args)
 {
     Q_D(KCMultiDialog);
@@ -626,7 +651,7 @@ KPageWidgetItem *KCMultiDialog::addModule(const KCModuleInfo &moduleInfo, KPageW
         }
     }
 
-    QObject::connect(kcm, QOverload<bool>::of(&KCModuleProxy::changed), this, [d]() {
+    QObject::connect(kcm, qOverload<bool>(&KCModuleProxy::changed), this, [d]() {
         d->_k_clientChanged();
     });
 
@@ -640,6 +665,7 @@ KPageWidgetItem *KCMultiDialog::addModule(const KCModuleInfo &moduleInfo, KPageW
     }
     return item;
 }
+#endif
 
 void KCMultiDialog::clear()
 {
